@@ -21,28 +21,24 @@
 #include <libglom/libglom_config.h>
 
 #include <libglom/connectionpool_backends/postgres.h>
+#include <libglom/utils.h>
 #include <glibmm/i18n.h>
-#include <bakery/bakery.h>
-
-#ifdef GLOM_ENABLE_MAEMO
-# include <hildonmm/note.h>
-#else
-# include <gtkmm/messagedialog.h>
-#endif
-
 
 // Uncomment to see debug messages
-// #define GLOM_CONNECTION_DEBUG
+//#define GLOM_CONNECTION_DEBUG
 
 namespace
 {
 
 static Glib::ustring create_auth_string(const Glib::ustring& username, const Glib::ustring& password)
 {
-  return "USERNAME=" + username + ";PASSWORD=" + password;
+  if(username.empty() and password.empty())
+    return Glib::ustring();
+  else
+    return "USERNAME=" + username + ";PASSWORD=" + password; //TODO: How should we quote and escape these?
 }
 
-}
+} //anonymous namespace
 
 namespace Glom
 {
@@ -61,7 +57,7 @@ float Postgres::get_postgres_server_version() const
   return m_postgres_server_version;
 }
 
-Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustring& host, const Glib::ustring& port, const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error)
+Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustring& host, const Glib::ustring& port, const Glib::ustring& database, const Glib::ustring& username, const Glib::ustring& password, std::auto_ptr<ExceptionConnection>& error) throw()
 {
   //We must specify _some_ database even when we just want to create a database.
   //This _might_ be different on some systems. I hope not. murrayc
@@ -70,44 +66,49 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
   const Glib::ustring cnc_string_main = "HOST=" + host + ";PORT=" + port;
   Glib::ustring cnc_string = cnc_string_main + ";DB_NAME=" + database;
 
-  //std::cout << "debug: connecting: cnc string: " << cnc_string << std::endl;
-#ifdef GLOM_CONNECTION_DEBUG          
-  std::cout << std::endl << "Glom: trying to connect on port=" << port << std::endl;
-#endif
-
   Glib::RefPtr<Gnome::Gda::Connection> connection;
   Glib::RefPtr<Gnome::Gda::DataModel> data_model;
 
+  const Glib::ustring auth_string = create_auth_string(username, password);   
+ 
+#ifdef GLOM_CONNECTION_DEBUG          
+  std::cout << std::endl << "DEBUG: Glom: trying to connect on port=" << port << std::endl;
+  std::cout << "DEBUG: ConnectionPoolBackends::Postgres::attempt_connect(): cnc_string=" << cnc_string << std::endl;
+  std::cout << "  DEBUG: auth_string=" << auth_string << std::endl;
+#endif
+
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
-    Glib::ustring auth_string = create_auth_string(username, password);
-    connection = Gnome::Gda::Connection::open_from_string("PostgreSQL", cnc_string, auth_string);
-    
+    connection = Gnome::Gda::Connection::open_from_string("PostgreSQL", 
+      cnc_string, auth_string, 
+      Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE
+      );
     connection->statement_execute_non_select("SET DATESTYLE = 'ISO'");
     data_model = connection->statement_execute_select("SELECT version()");
   }
   catch(const Glib::Error& ex)
   {
 #else
-  std::auto_ptr<Glib::Error> error;
-  Glib::ustring auth_string = create_auth_string(username, password);
-  connection = Gnome::Gda::Connection::open_from_string("PostgreSQL", cnc_string, auth_string, Gnome::Gda::CONNECTION_OPTIONS_NONE, error);
+  std::auto_ptr<Glib::Error> ex;
+  connection = Gnome::Gda::Connection::open_from_string("PostgreSQL", 
+    cnc_string, auth_string,
+    Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE,
+    ex);
   
-  if(!error)
-      connection->statement_execute_non_select("SET DATESTYLE = 'ISO'", error);
+  if(!ex.get())
+    connection->statement_execute_non_select("SET DATESTYLE = 'ISO'", ex);
 
-  if(!error)
-      data_model = connection->statement_execute_select("SELECT version()", error);
+  if(!ex.get())
+    data_model = connection->statement_execute_select("SELECT version()", Gnome::Gda::STATEMENT_MODEL_RANDOM_ACCESS, ex);
 
-  if(glib_error.get())
+  if(!ex.get())
   {
-    const Glib::Error& ex = *glib_error;
 #endif
 
 #ifdef GLOM_CONNECTION_DEBUG
-    std::cout << "ConnectionPoolBackends::PostgresCentralHosted::attempt_connect(): Attempt to connect to database failed on port=" << port << ", database=" << database << ": " << ex.what() << std::endl;
-    std::cout << "ConnectionPoolBackends::PostgresCentralHosted::attempt_connect(): Attempting to connect without specifying the database." << std::endl;
+    std::cout << "ConnectionPoolBackends::Postgres::attempt_connect(): Attempt to connect to database failed on port=" << port << ", database=" << database << ": " << ex.what() << std::endl;
+    std::cout << "ConnectionPoolBackends::Postgres::attempt_connect(): Attempting to connect without specifying the database." << std::endl;
 #endif
 
     Glib::ustring cnc_string = cnc_string_main + ";DB_NAME=" + default_database;
@@ -116,10 +117,16 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
     try
     {
-      temp_conn = Gnome::Gda::Connection::open_from_string("PostgreSQL", cnc_string, auth_string);
-    } catch(const Glib::Error& ex) {}
+      temp_conn = Gnome::Gda::Connection::open_from_string("PostgreSQL", 
+        cnc_string, auth_string, 
+        Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
+    }
+    catch(const Glib::Error& ex)
+    {}
 #else
-    temp_conn = client->open_connection_from_string("PostgreSQL", cnc_string, auth_string, Gnome::Gda::CONNECTION_OPTIONS_NONE, glib_error);
+    temp_conn = Gnome::Gda::Connection::open_from_string("PostgreSQL", 
+      cnc_string, auth_string, 
+      Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE, ex);
 #endif
 
 #ifdef GLOM_CONNECTION_DEBUG
@@ -135,7 +142,11 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
 
   if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
   {
+#ifdef GLIBMM_EXCEPTIONS_ENABLED
     Gnome::Gda::Value value = data_model->get_value_at(0, 0);
+#else
+    Gnome::Gda::Value value = data_model->get_value_at(0, 0, ex);
+#endif
     if(value.get_value_type() == G_TYPE_STRING)
     {
       const Glib::ustring version_text = value.get_string();
@@ -145,7 +156,7 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
       if(posName != Glib::ustring::npos)
       {
         const Glib::ustring versionPart = version_text.substr(namePart.size());
-        m_postgres_server_version = strtof(versionPart.c_str(), NULL);
+        m_postgres_server_version = strtof(versionPart.c_str(), 0);
 
 #ifdef GLOM_CONNECTION_DEBUG
         std::cout << "  Postgres Server version: " << m_postgres_server_version << std::endl;
@@ -157,8 +168,7 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
   return connection;
 }
 
-#ifndef GLOM_ENABLE_CLIENT_ONLY
-bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vecConstFields& old_fields, const type_vecConstFields& new_fields, std::auto_ptr<Glib::Error>& error)
+bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const type_vec_const_fields& old_fields, const type_vec_const_fields& new_fields, std::auto_ptr<Glib::Error>& error)
 {
   static const char* TRANSACTION_NAME = "glom_change_columns_transaction";
   static const gchar* TEMP_COLUMN_NAME = "glom_temp_column"; // TODO: Find a unique name.
@@ -207,9 +217,9 @@ bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connec
                                          "WHEN " + field_name_old_quoted + " IS NULL THEN false END)";
             }
             else if(old_field_type == Field::TYPE_TEXT)
-              conversion_command = "(" + field_name_old_quoted + " !~~* \'false\')"; // !~~* means ! ILIKE
+              conversion_command = '(' + field_name_old_quoted + " !~~* \'false\')"; // !~~* means ! ILIKE
             else // Dates and Times:
-              conversion_command = "(" + field_name_old_quoted + " IS NOT NULL)";
+              conversion_command = '(' + field_name_old_quoted + " IS NOT NULL)";
             break;
           }
 
@@ -383,17 +393,20 @@ bool Postgres::attempt_create_database(const Glib::ustring& database_name, const
     return false;
   }
 #else
-  std::auto_ptr<Glib::Error> error;
+  std::auto_ptr<Glib::Error> ex;
   op = Gnome::Gda::ServerOperation::prepare_create_database("PostgreSQL",
                                                             database_name,
-                                                            error);
-  if(error)
+                                                            ex);
+  if(ex.get())
     return false;
 
   //TODO: Why is this here but not in the EXCEPTIONS_ENABLED part?
-  op = cnc->create_operation(Gnome::Gda::SERVER_OPERATION_CREATE_DB, set, error);
-  if(error)
+  // jhs: Does look like a bug to me, shouldn't be there
+#if 0
+  op = cnc->create_operation(Gnome::Gda::SERVER_OPERATION_CREATE_DB, set, ex.get());
+  if(ex.get())
     return false;
+#endif
 #endif
   g_assert(op);
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
@@ -410,54 +423,49 @@ bool Postgres::attempt_create_database(const Glib::ustring& database_name, const
     error.reset(new Glib::Error(ex));
     return false;
   }
-#else
+#else //GLIBMM_EXCEPTIONS_ENABLED
   op->set_value_at("/SERVER_CNX_P/HOST", host, error);
   op->set_value_at("/SERVER_CNX_P/PORT", port, error);
   op->set_value_at("/SERVER_CNX_P/ADM_LOGIN", username, error);
   op->set_value_at("/SERVER_CNX_P/ADM_PASSWORD", password, error);
 
   if(error.get() == 0)
-    op->perform_create_database("PostgreSQL");
+    op->perform_create_database("PostgreSQL", ex);
   else
     return false;
-#endif
+  if (error.get())
+    return false;
+#endif //GLIBMM_EXCEPTIONS_ENABLED
 
   return true;
 }
-#endif
 
-bool Postgres::check_postgres_gda_client_is_available_with_warning()
+bool Postgres::check_postgres_gda_client_is_available()
 {
-  // TODO_gda:
-#if 0
-  Glib::RefPtr<Gnome::Gda::Client> gda_client = Gnome::Gda::Client::create();
-  if(gda_client)
+  //This API is horrible.
+  //See libgda bug http://bugzilla.gnome.org/show_bug.cgi?id=575754
+  Glib::RefPtr<Gnome::Gda::DataModel> model = Gnome::Gda::Config::list_providers();
+  if(model && model->get_n_columns() && model->get_n_rows())
   {
-    //Get the list of providers:
-    typedef std::list<Gnome::Gda::ProviderInfo> type_list_of_provider_info;
-    type_list_of_provider_info providers = Gnome::Gda::Config::get_providers();
+    Glib::RefPtr<Gnome::Gda::DataModelIter> iter = model->create_iter();
 
-    //Examine the information about each Provider:
-    for(type_list_of_provider_info::const_iterator iter = providers.begin(); iter != providers.end(); ++iter)
-    { 
-      const Gnome::Gda::ProviderInfo& info = *iter;
-      if(info.get_id() == "PostgreSQL")
+    do
+    {
+      //See http://library.gnome.org/devel/libgda/unstable/libgda-40-Configuration.html#gda-config-list-providers
+      //about the columns of this DataModel:
+      const Gnome::Gda::Value name = iter->get_value_at(0);
+      if(name.get_value_type() != G_TYPE_STRING)
+        continue;
+
+      const Glib::ustring name_as_string = name.get_string();
+      //std::cout << "DEBUG: Provider name:" << name_as_string << std::endl;
+      if(name_as_string == "PostgreSQL")
         return true;
     }
+    while(iter->move_next());
   }
 
-  const Glib::ustring message = _("Your installation of Glom is not complete, because the PostgreSQL libgda provider is not available on your system. This provider is needed to access Postgres database servers.\n\nPlease report this bug to your vendor, or your system administrator so it can be corrected.");
-#ifndef GLOM_ENABLE_MAEMO
-  /* The Postgres provider was not found, so warn the user: */
-  Gtk::MessageDialog dialog(Bakery::App_Gtk::util_bold_message(_("Incomplete Glom Installation")), true /* use_markup */, Gtk::MESSAGE_ERROR, Gtk::BUTTONS_OK, true /* modal */);
-  dialog.set_secondary_text(message);
-  dialog.run();
-#else
-  Hildon::Note note(Hildon::NOTE_TYPE_INFORMATION, message);
-  note.run();
-#endif
-#endif
-  return true;
+  return false;
 }
 
 }
