@@ -145,7 +145,7 @@ void Field::set_field_info(const Glib::RefPtr<Gnome::Gda::Column>& fieldinfo)
   {
     cur_type = get_gda_type_for_glom_type(get_glom_type());
 
-    const FieldTypes* pFieldTypes = NULL;
+    const FieldTypes* pFieldTypes = 0;
 
     ConnectionPool* pConnectionPool = ConnectionPool::get_instance();
     if(pConnectionPool)
@@ -168,7 +168,7 @@ void Field::set_field_info(const Glib::RefPtr<Gnome::Gda::Column>& fieldinfo)
     // TODO: Basically copied from set_default_value(). Maybe this check should
     // be moved into an extra function.
     GType cur_type = get_gda_type_for_glom_type(get_glom_type());
-    const FieldTypes* pFieldTypes = NULL;
+    const FieldTypes* pFieldTypes = 0;
 
     ConnectionPool* pConnectionPool = ConnectionPool::get_instance();
     if(pConnectionPool)
@@ -300,13 +300,25 @@ Glib::ustring Field::to_file_format(const Gnome::Gda::Value& value, glom_field_t
     else
     {
       gchar* str = gda_binary_to_string(gdabinary, 0);
-      return (str) ? Glib::ustring(Glib::ScopedPtr<char>(str).get())
-        : Glib::ustring();
+      Glib::ustring result = (str) ? 
+        Glib::ustring(Glib::ScopedPtr<char>(str).get()) : Glib::ustring();
+
+      //Avoid arbitrary newlines in this text.
+      //See libgda bug: https://bugzilla.gnome.org/show_bug.cgi?id=597390
+      result = Utils::string_replace(result, "\n", "\\012");
+
+      //Avoid arbitrary newlines in this text.
+      //See libgda bug: https://bugzilla.gnome.org/show_bug.cgi?id=597390
+      result = Utils::string_replace(result, "\r", "\\015");
+
+      //Escape any quotes in this text:
+      //See libgda bug: https://bugzilla.gnome.org/show_bug.cgi?id=597390
+      return Utils::string_replace(result, "\"", "\\042");
     }
   }
   
   NumericFormat format_ignored; //Because we use ISO format.
-  const Glib::ustring result = Conversions::get_text_for_gda_value(glom_type, value, std::locale() /* SQL uses the C locale */, format_ignored, true /* ISO standard */);
+  const Glib::ustring result = Conversions::get_text_for_gda_value(glom_type, value, std::locale::classic() /* SQL uses the C locale */, format_ignored, true /* ISO standard */);
   
   //Escape " as "", as specified by the CSV RFC:
   return Utils::string_replace(result, GLOM_QUOTE_FOR_FILE_FORMAT, GLOM_QUOTE_FOR_FILE_FORMAT GLOM_QUOTE_FOR_FILE_FORMAT);
@@ -465,7 +477,7 @@ void Field::set_default_value(const Gnome::Gda::Value& value)
 
   // Verify that the value matches the type of the field.
   GType cur_type = get_gda_type_for_glom_type(get_glom_type());
-  const FieldTypes* pFieldTypes = NULL;
+  const FieldTypes* pFieldTypes = 0;
 
   ConnectionPool* pConnectionPool = ConnectionPool::get_instance();
   if(pConnectionPool)
