@@ -22,9 +22,9 @@
 #define DIALOG_FIELDCALCULATION_H
 
 #include <gtkmm.h>
-#include <libglademm.h>
-#include <glom/libglom/data_structure/field.h>
-#include "../../base_db.h"
+#include <gtkmm/builder.h>
+#include <libglom/data_structure/field.h>
+#include <glom/base_db.h>
 #include <gtksourceviewmm/sourceview.h>
 
 namespace Glom
@@ -36,13 +36,13 @@ class Dialog_FieldCalculation
 
 {
 public:
-  Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade);
+  Dialog_FieldCalculation(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder);
   virtual ~Dialog_FieldCalculation();
 
   void set_field(const sharedptr<const Field>& field, const Glib::ustring& table_name);
   sharedptr<Field> get_field() const;
 
-protected:
+private:
   void on_button_test();
   bool check_for_return_statement(const Glib::ustring& calculation);
 
